@@ -559,7 +559,12 @@ render <- function(input,
 
   # call any pre_knit handler
   if (!is.null(output_format$pre_knit)) {
-    output_format$pre_knit(input = original_input)
+    if ('...' %in% names(formals(output_format$pre_knit))) {
+      output_format$pre_knit(input = original_input, metadata = front_matter)
+    } else {
+      warning("The 'pre_knit' function of the output format should have a '...' argument.")
+      output_format$pre_knit(input = original_input)
+    }
   }
 
   # function used to call post_knit handler
